Stan Math Library: stan/math/rev/core/vvv_vari.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

vvv_vari.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_CORE_VVV_VARI_HPP
2 #define STAN_MATH_REV_CORE_VVV_VARI_HPP
3
4 #include <stan/math/rev/core/vari.hpp>
5
6 namespace stan {
7
8 namespace math {
9
10 class op_vvv_vari : public vari {
11 protected:
12 vari* avi_;
13 vari* bvi_;
14 vari* cvi_;
15 public:
16 op_vvv_vari(double f, vari* avi, vari* bvi, vari* cvi) :
17 vari(f),
18 avi_(avi),
19 bvi_(bvi),
20 cvi_(cvi) {
21 }
22 };
23
24 }
25 }
26 #endif
stan::math::op_vvv_vari::cvi_
vari * cvi_
Definition: vvv_vari.hpp:14
vari.hpp
stan::math::op_vvv_vari
Definition: vvv_vari.hpp:10
stan
Definition: log_sum_exp.hpp:8
stan::math::op_vvv_vari::avi_
vari * avi_
Definition: vvv_vari.hpp:12
stan::math::vari
The variable implementation base class.
Definition: vari.hpp:30
stan::math::op_vvv_vari::op_vvv_vari
op_vvv_vari(double f, vari *avi, vari *bvi, vari *cvi)
Definition: vvv_vari.hpp:16
stan::math::op_vvv_vari::bvi_
vari * bvi_
Definition: vvv_vari.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.